#!/bin/sh

if [ x$1 = x ] ; then
LG=fr
else
LG=`basename $1 .po`
fi

cd `dirname $0`

echo "generation of $LG.mo from $LG.po... "
xgettext --keyword="_" --keyword="translate"  ../bins
#xpot --keyword="_" --keyword="translate" ../bins >messages.po 
touch $LG.po
mv $LG.po $LG.po.old
msgmerge $LG.po.old messages.po >$LG.po
msgfmt -o $LG.mo $LG.po

echo
echo "Now Copy the $LG.mo file to"\
 "/usr/local/share/locale/$LG/LC_MESSAGES/bins.mo"
